<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsAbout extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-about';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'About', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-user-circle-o';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'about' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content_about',
            [
                'label' => esc_html__( 'About', 'bdevs-elementor' ),
            ]   
        );    
        $this->add_control(
            'years',
            [
                'label'       => __( 'Years:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your years', 'bdevs-elementor' ),
                'default'     => __( '10', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'after_years',
            [
                'label'       => __( 'Text After Years:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your text', 'bdevs-elementor' ),
                'default'     => __( 'Years of experience', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'name',
            [
                'label'       => __( 'Name:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your name', 'bdevs-elementor' ),
                'default'     => __( 'John Smith', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );     
        $this->add_control(
            'heading',
            [
                'label'       => __( 'Heading:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
                'default'     => __( 'About Me', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'text',
            [
                'label'       => __( 'Text:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your text', 'bdevs-elementor' ),
                'default'     => __( 'This is text ', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'link_button',
            [
                'label'       => __( 'Link Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your link', 'bdevs-elementor' ),
                'default'     => __( '#', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button',
            [
                'label'       => __( 'Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your button', 'bdevs-elementor' ),
                'default'     => __( 'Download CV', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'icon',
            [
                'label'   => esc_html__( 'Icon', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );   
        $this->add_control(
            'signature',
            [
                'label'   => esc_html__( 'Signature:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        ); 
        $this->end_controls_section();
        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );
        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );
        $this->end_controls_section();

    }

    public function render() {
    $settings  = $this->get_settings_for_display();
    extract($settings); ?>
    <div class="orido_tm_section" id="about">
        <div class="orido_tm_about">
            <div class="about_in">
                <div class="left">
                    <div class="box">
                        <?php if(isset($settings['years']) && $settings['years'] != ''){?>
                        <h3 class="year"><?php print wp_kses_post($settings['years']); ?></h3>
                        <?php } ?>
                        <?php if(isset($settings['after_years']) && $settings['after_years'] != ''){?>
                        <span class="experience"><?php print wp_kses_post($settings['after_years']); ?></span>
                        <?php } ?>
                        <?php if(isset($settings['name']) && $settings['name'] != ''){?>
                        <h3 class="name"><?php print wp_kses_post($settings['name']); ?></h3>
                        <?php } ?>
                    </div>
                </div>
                <div class="right">
                    <?php if(isset($settings['heading']) && $settings['heading'] != ''){?>
                    <div class="orido_tm_main_title">
                        <h3><span><?php print wp_kses_post($settings['heading']); ?></span></h3>
                    </div>
                    <?php } ?>
                    <?php if(isset($settings['text']) && $settings['text'] != ''){?>
                    <div class="text">
                        <p><?php print wp_kses_post($settings['text']); ?></p>
                    </div>
                    <?php } ?>
                    <div class="short">
                        <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
                        <div class="orido_tm_boxed_button">
                            <a href="<?php print wp_kses_post($settings['link_button']); ?>" download><?php print wp_kses_post($settings['button']); ?> 
                            <?php if(isset($settings['icon']['url']) && $settings['icon']['url'] != ''){?>
                            <img class="svg" src="<?php echo wp_kses_post($settings['icon']['url']); ?>" alt="" />
                            <?php } ?>
                        </a>
                        </div>
                        <?php } ?>
                        <?php if(isset($settings['signature']['url']) && $settings['signature']['url'] != ''){?>
                        <img src="<?php echo wp_kses_post($settings['signature']['url']); ?>" alt="" />
                        <?php } ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php if (is_admin()) { ?>
    <script type="text/javascript">
        var data            = jQuery('*[data-img-url]');
        data.each(function(){
            var element         = jQuery(this);
            var url             = element.data('img-url');
            element.css({backgroundImage: 'url('+url+')'});
        });
    </script>   
    <?php } ?>
    <?php
    }
}


