<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsBanner extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-banner';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Banner', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-banner';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'banner' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        
        $this->start_controls_section(
            'section_content_left',
            [
                'label' => esc_html__( 'Banner Left', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'name',
            [
                'label'       => __( 'Name:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your name', 'bdevs-elementor' ),
                'default'     => __( 'John Smith', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'icon',
            [
                'label'   => esc_html__( 'Icon', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->add_control(
            'job',
            [
                'label'       => __( 'Job:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your job', 'bdevs-elementor' ),
                'default'     => __( 'Visual Designer', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your description', 'bdevs-elementor' ),
                'default'     => __( 'This is description', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'link_button',
            [
                'label'       => __( 'Link Button 1:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter link button', 'bdevs-elementor' ),
                'default'     => __( '#contact' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button',
            [
                'label'       => __( 'Button 1:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter button', 'bdevs-elementor' ),
                'default'     => __( 'Say Hello' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'send_icon',
            [
                'label'   => esc_html__( 'Send Icon', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->add_control(
            'link_button_2',
            [
                'label'       => __( 'Link Button 2:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter link button 2', 'bdevs-elementor' ),
                'default'     => __( '#portfolio' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button_2',
            [
                'label'       => __( 'Button 2:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter button', 'bdevs-elementor' ),
                'default'     => __( 'My Work' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'top_arrow',
            [
                'label'   => esc_html__( 'Top Arrow', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->add_control(
            'follow_me',
            [
                'label'       => __( 'Follow Me:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter button', 'bdevs-elementor' ),
                'default'     => __( 'Follow me:' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Socials:', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'    => 'social_image',
                        'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                        'dynamic' => [ 'active' => true ],
                    ],
                    [
                        'name'        => 'link',
                        'label'       => esc_html__( 'Link:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '#' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                ],
            ]
        ); 
        $this->add_control(
            'down_button_link',
            [
                'label'       => __( 'Down Button Link:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter button', 'bdevs-elementor' ),
                'default'     => __( '#about' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'down_button',
            [
                'label'   => esc_html__( 'Down Button', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'section_content_right',
            [
                'label' => esc_html__( 'Banner Right', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'avatar',
            [
                'label'   => esc_html__( 'Avatar', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );  
        $this->add_control(
            'link_video',
            [
                'label'       => __( 'Link Video:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your link', 'bdevs-elementor' ),
                'default'     => __( 'https://www.youtube.com/watch?v=7e90gBu4pas' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'spin_image',
            [
                'label'   => esc_html__( 'Spin Image', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->add_control(
            'play_button',
            [
                'label'   => esc_html__( 'Play Button', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->end_controls_section();

        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );
        $this->end_controls_section();

    }
    public function render() {
    $settings  = $this->get_settings_for_display();
    extract($settings); 
    ?> 
    <div class="orido_tm_hero" id="home">
        <div class="container">
            <div class="content">
                <div class="details">
                    <div class="short">
                        <?php if(isset($settings['name']) && $settings['name'] != ''){?>
                        <h3>
                            <?php print wp_kses_post($settings['name']); ?> 
                            <?php if(isset($settings['icon']['url']) && $settings['icon']['url'] != ''){?>
                            <img class="svg" src="<?php echo wp_kses_post($settings['icon']['url']);?>" alt="" />
                            <?php } ?>
                        </h3>
                        <?php } ?>
                        <?php if(isset($settings['job']) && $settings['job'] != ''){?>
                        <span class="job"><?php print wp_kses_post($settings['job']); ?></span>
                        <?php } ?>
                    </div>
                    <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                    <div class="text">
                        <p><?php print wp_kses_post($settings['description']); ?></p>
                    </div>
                    <?php } ?>
                    <div class="buttons">
                        <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
                        <div class="orido_tm_boxed_button">
                            <a class="anchor" href="<?php print wp_kses_post($settings['link_button']); ?>"><?php print wp_kses_post($settings['button']); ?>
                            <?php if(isset($settings['send_icon']['url']) && $settings['send_icon']['url'] != ''){?>
                            <img class="svg" src="<?php echo wp_kses_post($settings['send_icon']['url']);?>" alt="" />
                            <?php } ?>
                        </a>
                        </div>
                        <?php } ?>
                        <?php if(isset($settings['link_button_2']) && $settings['link_button_2'] != ''){?>
                        <div class="orido_tm_simple_button">
                            <a class="line_effect anchor" href="<?php print wp_kses_post($settings['link_button_2']); ?>"><?php print wp_kses_post($settings['button_2']); ?> 
                            <?php if(isset($settings['top_arrow']['url']) && $settings['top_arrow']['url'] != ''){?>
                            <img class="svg" src="<?php echo wp_kses_post($settings['top_arrow']['url']);?>" alt="" />
                            <?php } ?>
                        </a>
                        </div>
                        <?php } ?>
                    </div>
                </div>
                
            </div>
            <div class="orido_tm_follow">
                <?php if(isset($settings['follow_me']) && $settings['follow_me'] != ''){?>
                <span><?php print wp_kses_post($settings['follow_me']); ?></span>
                <?php } ?>
                <ul>
                    <?php foreach ( $settings['tabs'] as $item ) : ?>
                    <li><a href="<?php print wp_kses_post($item['link']); ?>"><img class="svg" src="<?php echo wp_kses_post($item['social_image']['url']); ?>" alt="" /></a></li>
                    <?php endforeach; ?>
                </ul>
            </div>
        </div>
        <?php if(isset($settings['down_button_link']) && $settings['down_button_link'] != ''){?>
        <div class="orido_tm_down">
            <a class="anchor" href="<?php print wp_kses_post($settings['down_button_link']); ?>">
                <img class="svg" src="<?php echo wp_kses_post($settings['down_button']['url']); ?>" alt="" />
            </a>
        </div>
        <?php } ?>
        <div class="avatar">
            <div class="img">
                <img src="<?php echo wp_kses_post($settings['avatar']['url']); ?>" alt="" />
                <?php if(isset($settings['link_video']) && $settings['link_video'] != ''){?>
                <div class="video_button">
                    <a class="popup-youtube" href="<?php print wp_kses_post($settings['link_video']); ?>">
                        <img class="anim_circle" src="<?php echo wp_kses_post($settings['spin_image']['url']); ?>" alt="" />
                        <img class="svg" src="<?php echo wp_kses_post($settings['play_button']['url']); ?>" alt="" />
                    </a>
                </div>
                <?php } ?>
            </div>
        </div>
    </div>
    <?php if (is_admin()) { ?>
    <script type="text/javascript">
        var data            = jQuery('*[data-img-url]');
        data.each(function(){
            var element         = jQuery(this);
            var url             = element.data('img-url');
            element.css({backgroundImage: 'url('+url+')'});
        });
    </script>   
    <?php } ?>            
    <?php
    }

}

