<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsContact extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-contact';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Contact', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-headphones';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'contact' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Contact', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'heading',
            [
                'label'       => __( 'Heading:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
                'default'     => __( 'Lets work together', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'description',
            [
                'label'       => __( 'Description:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your description', 'bdevs-elementor' ),
                'default'     => __( 'This is description', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'link_video',
            [
                'label'       => __( 'Link Video:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your link', 'bdevs-elementor' ),
                'default'     => __( 'https://www.youtube.com/watch?v=7e90gBu4pas', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'spin_image',
            [
                'label'   => esc_html__( 'Spin Image:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->add_control(
            'play_button',
            [
                'label'   => esc_html__( 'Play Button:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->add_control(
            'link_button',
            [
                'label'       => __( 'Link Button 1:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter link button', 'bdevs-elementor' ),
                'default'     => __( '#contact' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button',
            [
                'label'       => __( 'Button 1:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter button', 'bdevs-elementor' ),
                'default'     => __( 'Say Hello' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'send_icon',
            [
                'label'   => esc_html__( 'Send Icon', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
     	$this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Information:', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'choose_style',
                        'label'     => esc_html__( 'Choose Style', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            '1'  => esc_html__( 'Phone', 'bdevs-elementor' ),
                            '2'  => esc_html__( 'Email', 'bdevs-elementor' ),
                        ],
                        'default'   => '1',
                    ],
                    [
                        'name'        => 'title',
                        'label'       => esc_html__( 'Title:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Call:' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'detail',
                        'label'       => esc_html__( 'Detail:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '+ 123 456 7890' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                ],
            ]
        );
        $this->add_control(
            'image_1',
            [
                'label'   => esc_html__( 'Image 1:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        ); 
        $this->add_control(
            'image_2',
            [
                'label'   => esc_html__( 'Image 2:', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        ); 
        $this->add_control(
            'follow_me',
            [
                'label'       => __( 'Follow Me:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter button', 'bdevs-elementor' ),
                'default'     => __( 'Follow me:' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'tabs2',
            [
                'label' => esc_html__( 'Socials:', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'    => 'social_image',
                        'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
                        'type'    => Controls_Manager::MEDIA,
                        'default'     => esc_html__( '' , 'bdevs-elementor' ),
                        'dynamic' => [ 'active' => true ],
                    ],
                    [
                        'name'        => 'link',
                        'label'       => esc_html__( 'Link:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( '#' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                ],
            ]
        ); 
        $this->end_controls_section();

        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );
        $this->end_controls_section();

    }

    public function render() {
        $settings  = $this->get_settings_for_display();
        extract($settings); 
        ?>
        <div class="orido_tm_section" id="contact">
            <div class="orido_tm_contact">
                <div class="container">
                    <div class="infobox">
                        <div class="video_button">
                            <a class="popup-youtube" href="<?php print wp_kses_post($settings['link_video']); ?>">
                                <?php if(isset($settings['spin_image']['url']) && $settings['spin_image']['url'] != ''){?>
                                <img class="anim_circle" src="<?php echo wp_kses_post($settings['spin_image']['url']); ?>" alt="" />
                                <?php } ?>
                                <?php if(isset($settings['play_button']['url']) && $settings['play_button']['url'] != ''){?>
                                <img class="svg" src="<?php echo wp_kses_post($settings['play_button']['url']); ?>" alt="" />
                                <?php } ?>
                            </a>
                        </div>
                        <div class="text">
                            <?php if(isset($settings['heading']) && $settings['heading'] != ''){?>
                            <h3><?php print wp_kses_post($settings['heading']); ?></h3>
                            <?php } ?>
                            <?php if(isset($settings['description']) && $settings['description'] != ''){?>
                            <p><?php print wp_kses_post($settings['description']); ?></p>
                            <?php } ?>
                        </div>
                        <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
                        <div class="orido_tm_boxed_button">
                            <a href="<?php print wp_kses_post($settings['link_button']); ?>"><?php print wp_kses_post($settings['button']); ?>
                            <?php if(isset($settings['send_icon']['url']) && $settings['send_icon']['url'] != ''){?>
                            <img class="svg" src="<?php echo wp_kses_post($settings['send_icon']['url']);?>" alt="" />
                            <?php } ?>
                        </a>
                        </div>
                        <?php } ?>
                    </div>
                    <div class="connect">
                        <div class="left">
                            <ul>
                                <?php foreach ( $settings['tabs'] as $item ) : ?>
                                <?php if( wp_kses_post($item['choose_style']) == '1'): ?>
                                <li>
                                    <?php if(isset($item['title']) && $item['title'] != ''){?>
                                    <span  class="name"><?php print wp_kses_post($item['title']); ?></span>
                                    <?php } ?>
                                    <p><a class="line_effect" href="tel:<?php print wp_kses_post($item['detail']); ?>"><?php print wp_kses_post($item['detail']); ?></a></p>
                                </li>
                                <?php elseif( wp_kses_post($item['choose_style']) == '2'): ?>
                                <li>
                                    <?php if(isset($item['title']) && $item['title'] != ''){?>
                                    <span class="name"><?php print wp_kses_post($item['title']); ?></span>
                                    <?php } ?>
                                    <p><a class="line_effect" href="mailto:<?php print wp_kses_post($item['detail']); ?>"><?php print wp_kses_post($item['detail']); ?></a></p>
                                </li>
                                <?php endif; ?>
                                <?php endforeach; ?>
                            </ul>
                        </div>
                        <div class="right">
                            <div class="orido_tm_follow">
                                <?php if(isset($settings['follow_me']) && $settings['follow_me'] != ''){?>
                                <span><?php print wp_kses_post($settings['follow_me']); ?></span>
                                <?php } ?>
                                <ul>
                                    <?php foreach ( $settings['tabs2'] as $item2 ) : ?>
                                    <li><a href="<?php print wp_kses_post($item2['link']); ?>"><img class="svg" src="<?php echo wp_kses_post($item2['social_image']['url']); ?>" alt="" /></a></li>
                                    <?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
                <?php if(isset($settings['image_1']['url']) && $settings['image_1']['url'] != ''){?>
                <span class="element"><img class="svg" src="<?php echo wp_kses_post($settings['image_1']['url']); ?>" alt="" /></span>
                <?php } ?>
                <?php if(isset($settings['image_2']['url']) && $settings['image_2']['url'] != ''){?>
                <span class="element2"><img class="svg" src="<?php echo wp_kses_post($settings['image_2']['url']); ?>" alt="" /></span>
                <?php } ?>
            </div>
        </div>
        <?php if (is_admin()) { ?>
        <script type="text/javascript">
            var data            = jQuery('*[data-img-url]');
            data.each(function(){
                var element         = jQuery(this);
                var url             = element.data('img-url');
                element.css({backgroundImage: 'url('+url+')'});
            });
        </script>   
        <?php } ?>
    <?php
    }
}


