<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsExpertAreas extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-expert-areas';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Expert Areas', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs About widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-posts-justified';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs About widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'bdevs-elementor' ];
    }

    public function get_keywords() {
        return [ 'Expert Areas' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Expert Areas', 'bdevs-elementor' ),
            ]   
        );
        $this->add_control(
            'heading',
            [
                'label'       => __( 'Heading:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
                'default'     => __( 'My expert<br />areas', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'text',
            [
                'label'       => __( 'Text:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your text', 'bdevs-elementor' ),
                'default'     => __( 'This is text ', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'link_button',
            [
                'label'       => __( 'Link Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your link', 'bdevs-elementor' ),
                'default'     => __( '#', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'button',
            [
                'label'       => __( 'Button:', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your button', 'bdevs-elementor' ),
                'default'     => __( 'My Resume', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'icon',
            [
                'label'   => esc_html__( 'Icon', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->add_control(
            'tabs',
            [
                'label' => esc_html__( 'Items', 'bdevs-elementor' ),
                'type' => Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name'        => 'choose_style',
                        'label'     => esc_html__( 'Choose Style', 'bdevs-elementor' ),
                        'type'      => Controls_Manager::SELECT,
                        'dynamic' => [ 'active' => true ],
                        'options'   => [
                            '1'  => esc_html__( 'Skills', 'bdevs-elementor' ),
                            '2'  => esc_html__( 'Timeline', 'bdevs-elementor' ),
                        ],
                        'default'   => '1',
                    ],
                    [
                        'name'        => 'tab_name',
                        'label'       => esc_html__( 'Tab Name:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::TEXT,
                        'dynamic'     => [ 'active' => true ],
                        'default'     => esc_html__( 'Skills' , 'bdevs-elementor' ),
                        'label_block' => true,
                    ],
                    [
                        'name'        => 'details',
                        'label'       => esc_html__( 'Details:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::REPEATER,
                        'condition' => [
                            'choose_style' => '1'
                        ],
                        'fields' => [
                            [
                                'name'    => 'image_icon',
                                'label'   => esc_html__( 'Image Icon:', 'bdevs-elementor' ),
                                'type'    => Controls_Manager::MEDIA,
                                'default'     => esc_html__( '' , 'bdevs-elementor' ),
                                'dynamic' => [ 'active' => true ],
                            ],
                            [
                                'name'        => 'title',
                                'label'       => esc_html__( 'Title:', 'bdevs-elementor' ),
                                'type'        => Controls_Manager::TEXT,
                                'dynamic'     => [ 'active' => true ],
                                'default'     => esc_html__( 'Figma' , 'bdevs-elementor' ),
                                'label_block' => true,
                            ],
                            [
                                'name'        => 'percent',
                                'label'       => esc_html__( 'Percent:', 'bdevs-elementor' ),
                                'type'        => Controls_Manager::TEXTAREA,
                                'dynamic'     => [ 'active' => true ],
                                'default'     => esc_html__( '(90%)' , 'bdevs-elementor' ),
                                'label_block' => true,
                            ],
                        ]
                    ],
                    [
                        'name'        => 'details',
                        'label'       => esc_html__( 'Details:', 'bdevs-elementor' ),
                        'type'        => Controls_Manager::REPEATER,
                        'condition' => [
                            'choose_style' => '2'
                        ],
                        'fields' => [
                            [
                                'name'        => 'time',
                                'label'       => esc_html__( 'Time:', 'bdevs-elementor' ),
                                'type'        => Controls_Manager::TEXT,
                                'dynamic'     => [ 'active' => true ],
                                'default'     => esc_html__( '2021 - Present' , 'bdevs-elementor' ),
                                'label_block' => true,
                                
                            ],
                            [
                                'name'        => 'text',
                                'label'       => esc_html__( 'Text:', 'bdevs-elementor' ),
                                'type'        => Controls_Manager::TEXTAREA,
                                'dynamic'     => [ 'active' => true ],
                                'default'     => esc_html__( 'This is text' , 'bdevs-elementor' ),
                                'label_block' => true,
                            ],
                            [
                                'name'        => 'title',
                                'label'       => esc_html__( 'Title:', 'bdevs-elementor' ),
                                'type'        => Controls_Manager::TEXT,
                                'dynamic'     => [ 'active' => true ],
                                'default'     => esc_html__( 'Figma' , 'bdevs-elementor' ),
                                'label_block' => true,
                            ],
                        ]
                    ], 
                ],
            ]
        );
        $this->add_control(
            'top_arrow',
            [
                'label'   => esc_html__( 'Top Arrow', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );
        $this->end_controls_section();
        /** 
        *   Layout section 
        **/
        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );
        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );
        $this->end_controls_section();

    }

    public function render() {
    $settings  = $this->get_settings_for_display();
    extract($settings); ?>
    <div class="orido_tm_section">
        <div class="orido_tm_informations">
            <div class="container">
                <div class="informations_inner">
                    <div class="left">
                        <?php if(isset($settings['heading']) && $settings['heading'] != ''){?>
                        <div class="orido_tm_main_title">
                            <h3><span><?php print wp_kses_post($settings['heading']); ?></span></h3>
                        </div>
                        <?php } ?>
                        <?php if(isset($settings['text']) && $settings['text'] != ''){?>
                        <div class="text">
                            <?php print wp_kses_post($settings['text']); ?>
                        </div>
                        <?php } ?>
                        <?php if(isset($settings['link_button']) && $settings['link_button'] != ''){?>
                        <div class="orido_tm_boxed_button">
                            <a href="<?php print wp_kses_post($settings['link_button']); ?>"><?php print wp_kses_post($settings['button']); ?>
                            <?php if(isset($settings['icon']['url']) && $settings['icon']['url'] != ''){?>
                            <img class="svg" src="<?php echo wp_kses_post($settings['icon']['url']); ?>" alt="" />
                            <?php } ?>
                        </div>
                        <?php } ?>
                    </div>
                    <div class="right">
                        <div class="filter">
                            <ul>
                                <?php 
                                $i=0;
                                foreach ( $settings['tabs'] as $item ) : 
                                $i++;
                                ?>
                                <?php if ($i==1) { ?>                                  
                                <li>
                                    <a class="current" href="#" data-tab="tab_<?php echo $i;?>"><span><?php print wp_kses_post($item['tab_name']); ?></span> 
                                    <?php if(isset($settings['top_arrow']['url']) && $settings['top_arrow']['url'] != ''){?>
                                    <img class="svg" src="<?php echo wp_kses_post($settings['top_arrow']['url']); ?>" alt="" /></a>
                                    <?php } ?>
                                </li>
                                <?php } else { ?>
                                <li>
                                    <a href="#" data-tab="tab_<?php echo $i;?>"><span><?php print wp_kses_post($item['tab_name']); ?></span> 
                                    <?php if(isset($settings['top_arrow']['url']) && $settings['top_arrow']['url'] != ''){?>
                                    <img class="svg" src="<?php echo wp_kses_post($settings['top_arrow']['url']); ?>" alt="" /></a>
                                    <?php } ?>
                                </li>
                                <?php } ?>
                                <?php endforeach; ?>
                            </ul>
                            <span class="ccc"></span>
                        </div>
                        <div class="content">
                            <?php 
                            $j=0;
                            foreach ( $settings['tabs'] as $item ) : 
                            $j++;
                            ?>
                            <?php if ($j==1) { ?>
                            <div id="tab_<?php echo $j;?>" class="wrapper current">
                            <?php } else { ?>
                            <div id="tab_<?php echo $j;?>" class="wrapper">
                            <?php } ?>
                                <?php if( wp_kses_post($item['choose_style']) == '1'): ?>
                                <div class="skillbox">
                                    <ul>
                                        <?php foreach ( $item['details'] as $detail ) :  ?>
                                        <li>
                                            <div class="list_inner">
                                                <?php if(isset($detail['image_icon']['url']) && $detail['image_icon']['url'] != ''){?>
                                                <span class="icon"><span class="in"><img class="svg" src="<?php echo wp_kses_post($detail['image_icon']['url']); ?>" alt="" /></span></span>
                                                <?php } ?>
                                                <p class="name"><?php print wp_kses_post($detail['title']); ?> <span><?php print wp_kses_post($detail['percent']); ?></span></p>
                                            </div>
                                        </li>
                                        <?php endforeach; ?>
                                    </ul>
                                </div>
                                <?php elseif( wp_kses_post($item['choose_style']) == '2'): ?>
                                <div class="timelinebox">
                                    <ul>
                                        <?php foreach ( $item['details'] as $detail ) :  ?>
                                        <li>
                                            <div class="list_inner">
                                                <div class="time">
                                                    <?php if(isset($detail['time']) && $detail['time'] != ''){?>
                                                    <span class="year"><?php print wp_kses_post($detail['time']); ?></span>
                                                    <?php } ?>
                                                    <?php if(isset($detail['text']) && $detail['text'] != ''){?>
                                                    <span class="company"><?php print wp_kses_post($detail['text']); ?></span>
                                                    <?php } ?>
                                                </div>
                                                <?php if(isset($detail['title']) && $detail['title'] != ''){?>
                                                <div class="job">
                                                    <h3><span><?php print wp_kses_post($detail['title']); ?></span></h3>
                                                </div>
                                                <?php } ?>
                                            </div>
                                        </li>
                                        <?php endforeach; ?>
                                    </ul>
                                </div>
                                <?php endif; ?>
                            </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php
    }
}


